package com.lqkj.business.service;

import com.lqkj.business.entity.CameraInfo;
import com.lqkj.business.entity.CmsNews;
import com.lqkj.business.mapper.CameraInfoMapper;
import com.lqkj.common.utils.uuid.IdUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;

/**
 * 监控信息Service业务层处理
 *
 * @author lh
 * @date 2022-09-30
 */
@Service
public class CameraInfoService
{
    @Autowired
    private CameraInfoMapper cameraInfoMapper;

    /**
     * 查询监控信息
     *
     * @param cameraId 监控信息主键
     * @return 监控信息
     */

    public CameraInfo selectCameraInfoByCameraId(String cameraId)
    {
        return cameraInfoMapper.selectCameraInfoByCameraId(cameraId);
    }

    /**
     * 查询监控信息列表
     *
     * @param cameraInfo 监控信息
     * @return 监控信息
     */
    public List<CameraInfo> selectCameraInfoList(CameraInfo cameraInfo)
    {
        return cameraInfoMapper.selectCameraInfoList(cameraInfo);
    }

    /**
     * 新增监控信息
     *
     * @param cameraInfo 监控信息
     * @return 结果
     */

    public int insertCameraInfo(CameraInfo cameraInfo)
    {
        cameraInfo.setCreateTime(LocalDateTime.now());
        cameraInfo.setCameraId(IdUtils.simpleUUID());
        return cameraInfoMapper.insertCameraInfo(cameraInfo);
    }

    /**
     * 修改监控信息
     *
     * @param cameraInfo 监控信息
     * @return 结果
     */

    public int updateCameraInfo(CameraInfo cameraInfo)
    {
        cameraInfo.setUpdateTime(LocalDateTime.now());
        return cameraInfoMapper.updateCameraInfo(cameraInfo);
    }

    /**
     * 批量删除监控信息
     *
     * @param cameraIds 需要删除的监控信息主键
     * @return 结果
     */

    public int deleteCameraInfoByCameraIds(String[] cameraIds)
    {
        return cameraInfoMapper.deleteCameraInfoByCameraIds(cameraIds);
    }

    /**
     * 删除监控信息信息
     *
     * @param cameraId 监控信息主键
     * @return 结果
     */

    public int deleteCameraInfoByCameraId(String cameraId)
    {
        return cameraInfoMapper.deleteCameraInfoByCameraId(cameraId);
    }

    public int updateOnlineStatusByIndexCode(CameraInfo cameraInfo){
        return cameraInfoMapper.updateOnlineStatusByIndexCode(cameraInfo);
    }

    public int updateOnlineStatusById(CameraInfo cameraInfo){
        return cameraInfoMapper.updateOnlineStatusById(cameraInfo);
    }


}