package com.lqkj.business.service;

import java.util.List;
import java.time.LocalDateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.lqkj.business.mapper.DeviceCategoryMapper;
import com.lqkj.business.entity.DeviceCategory;
import com.lqkj.common.utils.uuid.IdUtils;
/**
 * 设备分类Service业务层处理
 *
 * @author lqkj
 * @date 2023-03-14
 */
@Service
public class DeviceCategoryService
{
    @Autowired
    private DeviceCategoryMapper deviceCategoryMapper;

    /**
     * 查询设备分类
     *
     * @param categoryId 设备分类主键
     * @return 设备分类
     */

    public DeviceCategory selectDeviceCategoryByCategoryId(Integer categoryId)
    {
        return deviceCategoryMapper.selectDeviceCategoryByCategoryId(categoryId);
    }

    /**
     * 查询设备分类列表
     *
     * @param deviceCategory 设备分类
     * @return 设备分类
     */
    public List<DeviceCategory> selectDeviceCategoryList(DeviceCategory deviceCategory)
    {
        return deviceCategoryMapper.selectDeviceCategoryList(deviceCategory);
    }

    /**
     * 新增设备分类
     *
     * @param deviceCategory 设备分类
     * @return 结果
     */

    public int insertDeviceCategory(DeviceCategory deviceCategory)
    {
        deviceCategory.setCreateTime(LocalDateTime.now());
        return deviceCategoryMapper.insertDeviceCategory(deviceCategory);
    }

    /**
     * 修改设备分类
     *
     * @param deviceCategory 设备分类
     * @return 结果
     */

    public int updateDeviceCategory(DeviceCategory deviceCategory)
    {
        deviceCategory.setUpdateTime(LocalDateTime.now());
        return deviceCategoryMapper.updateDeviceCategory(deviceCategory);
    }

    /**
     * 批量删除设备分类
     *
     * @param categoryIds 需要删除的设备分类主键
     * @return 结果
     */

    public int deleteDeviceCategoryByCategoryIds(Integer[] categoryIds)
    {
        return deviceCategoryMapper.deleteDeviceCategoryByCategoryIds(categoryIds);
    }

    /**
     * 删除设备分类信息
     *
     * @param categoryId 设备分类主键
     * @return 结果
     */

    public int deleteDeviceCategoryByCategoryId(Integer categoryId)
    {
        return deviceCategoryMapper.deleteDeviceCategoryByCategoryId(categoryId);
    }

    public List<DeviceCategory> selectParentCategoryList()
    {
        return deviceCategoryMapper.selectParentCategoryList();
    }
}
