package com.lqkj.camera.util;


import com.alibaba.fastjson.JSONObject;
import com.hikvision.artemis.sdk.ArtemisHttpUtil;
import com.hikvision.artemis.sdk.config.ArtemisConfig;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.Map;

/**
 * 海康视频调阅工具类
 */
public class HIKCameraUtils {

    private static Logger logger = LoggerFactory.getLogger("HIK camera api");

    private static HIKCameraUtils hikCameraUtils;

    private static String HTTPProtocol = "https";

    private static String host;

    private static String appKey;

    private static String appSecret;

    private HIKCameraUtils(){}

    private HIKCameraUtils(String host, String appKey, String appSecret, String httpProtocol){
        this.host = host;
        this.appKey = appKey;
        this.appSecret = appSecret;
        this.HTTPProtocol = httpProtocol;
    }

    /**
     * 获得一个单一实例
     * @return MD5
     */
    public static synchronized HIKCameraUtils getDefaultInstance(String host,
                                                                 String appKey,
                                                                 String appSecret,
                                                                 String httpProtocol){
        if(hikCameraUtils==null){
            hikCameraUtils = new HIKCameraUtils(host, appKey, appSecret, httpProtocol);
        }
        return hikCameraUtils;
    }

    /**
     * 获取视频格式预览（实时）流地址
     * @return
     */
    public String getCameraPreviewURL (String body){

        /**
         * STEP1：设置平台参数，根据实际情况,设置host appkey appsecret 三个参数.
         */
        ArtemisConfig.host = host; // artemis网关服务器ip端口
        ArtemisConfig.appKey = appKey;  // 秘钥appkey
        ArtemisConfig.appSecret = appSecret;// 秘钥appSecret

        /**
         * STEP2：设置OpenAPI接口的上下文
         */
        final String ARTEMIS_PATH = "/artemis";

        /**
         * STEP3：设置接口的URI地址
         */
        final String previewURLsApi = ARTEMIS_PATH + "/api/video/v1/cameras/previewURLs";
        Map<String, String> path = new HashMap<String, String>(2) {
            {
                put(HTTPProtocol + "://", previewURLsApi);//根据现场环境部署确认是http还是https
            }
        };

        /**
         * STEP4：设置参数提交方式
         */
        String contentType = "application/json";

        /**
         * STEP：调用接口
         */
        String result = ArtemisHttpUtil.doPostStringArtemis(path, body, null, null, contentType , null);// post请求application/json类型参数
        JSONObject resultJson = JSONObject.parseObject(result);
        try {
            return resultJson.getJSONObject("data").getString("url");
        } catch (Exception e) {
            logger.error(result);
            return null;
        }
    }

    /**
     * 分页获取监控设备列表
     * @return
     */
    public String pageQueryCamerasWithStatus (Integer pageSize, Integer pageNo){

        /**
         * STEP1：设置平台参数，根据实际情况,设置host appkey appsecret 三个参数.
         */
        ArtemisConfig.host = host; // artemis网关服务器ip端口
        ArtemisConfig.appKey = appKey;  // 秘钥appkey
        ArtemisConfig.appSecret = appSecret;// 秘钥appSecret

        /**
         * STEP2：设置OpenAPI接口的上下文
         */
        final String ARTEMIS_PATH = "/artemis";

        /**
         * STEP3：设置接口的URI地址
         */
        final String camerasDataApi = ARTEMIS_PATH + "/api/nms/v1/online/camera/get";
        Map<String, String> path = new HashMap<String, String>(2) {
            {
                put(HTTPProtocol + "://", camerasDataApi);//根据现场环境部署确认是http还是https
            }
        };

        /**
         * STEP4：设置参数提交方式
         */
        String contentType = "application/json";

        /**
         * STEP5：组装请求参数
         */
        JSONObject jsonBody = new JSONObject();
        jsonBody.put("pageSize", pageSize);
        jsonBody.put("pageNo", pageNo);
        String body = jsonBody.toJSONString();
        /**
         * STEP6：调用接口
         */
        return ArtemisHttpUtil.doPostStringArtemis(path, body, null, null, contentType , null);// post请求application/json类型参数

    }

    public static void main(String[] args) {
        String body = "{\"cameraIndexCode\":\"06b9bc8db4764bc984364d5fe555ce5b\",\"streamType\":1,\"protocol\":\"hls\",\"transmode\":1 }";
        String result = getDefaultInstance("10.22.3.60:443",
                "23644070",
                "iTjN7VDYx9eNbPUEPiKw",
                "https").getCameraPreviewURL(body);
        System.out.println("result结果示例: " + result);
    }

}
