package com.lqkj.common.utils.poi;

import org.apache.poi.xwpf.usermodel.XWPFDocument;
import org.apache.poi.xwpf.usermodel.XWPFRun;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlToken;
import org.openxmlformats.schemas.drawingml.x2006.main.CTNonVisualDrawingProps;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPositiveSize2D;
import org.openxmlformats.schemas.drawingml.x2006.wordprocessingDrawing.CTInline;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTDrawing;

/**
 * 文档操作图片工具类
 * @author: lh
 */
public class ImageUtil {
    /**
     * 图片类型枚举
     */
    public enum ImageType {

        /**
         * 支持四种类型 JPG/JPEG, GIT, BMP, PNG
         */
        JPG("JPG", XWPFDocument.PICTURE_TYPE_JPEG),
        JPEG("JPEG", XWPFDocument.PICTURE_TYPE_JPEG),
        GIF("GIF", XWPFDocument.PICTURE_TYPE_GIF),
        BMP("BMP", XWPFDocument.PICTURE_TYPE_GIF),
        PNG("PNG", XWPFDocument.PICTURE_TYPE_PNG)
        ;
        private String name;
        private Integer typeId;
        ImageType(String name, Integer type) {
            this.name = name;
            this.typeId = type;
        }

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

        public Integer getTypeId() {
            return typeId;
        }

        public void setTypeId(Integer typeId) {
            this.typeId = typeId;
        }
    }

    /**
     * 插入环绕类型图片
     * @param run
     * @param blipId
     * @param id
     * @param width
     * @param height

     */
    public static void createAnchorPicture(XWPFRun run, String blipId, int id, int width, int height, boolean behind, String align ) {
        final int EMU = 9525;
        width *= EMU;
        height *= EMU;
        CTDrawing drawing = run.getCTR().addNewDrawing();
        String xml = "<wp:anchor distT=\"0\" distB=\"0\" distL=\"0\" distR=\"0\" simplePos=\"0\" relativeHeight=\"0\" behindDoc=\"" + (behind ? 1 : 0) +"\" locked=\"0\" layoutInCell=\"1\" allowOverlap=\"1\" " +
                " xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\"" +
                " xmlns:wp14=\"http://schemas.microsoft.com/office/word/2010/wordprocessingDrawing\"" +
                " xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\"  >" +
                "<wp:simplePos x=\"0\" y=\"0\"/>" +
                "<wp:positionH relativeFrom=\"column\">" +
                "<wp:align>" + align +"</wp:align>" +
                "</wp:positionH>" +
                "<wp:positionV relativeFrom=\"paragraph\">" +
                "<wp:posOffset>0</wp:posOffset>" +
                "</wp:positionV>" +
                "<wp:extent cx=\"" + width +"\" cy=\"" + height +"\"/>" +
                "<wp:effectExtent l=\"0\" t=\"0\" r=\"0\" b=\"0\"/>" +
                "<wp:wrapNone/>" +
                "<wp:docPr id=\"" + id +"\" name=\"图片 " + id +"\"/>" +
                "<wp:cNvGraphicFramePr>" +
                "<a:graphicFrameLocks xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" noChangeAspect=\"1\"/>" +
                "</wp:cNvGraphicFramePr>" +
                "<a:graphic xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\">" +
                "<a:graphicData uri=\"http://schemas.openxmlformats.org/drawingml/2006/picture\">" +
                "<pic:pic xmlns:pic=\"http://schemas.openxmlformats.org/drawingml/2006/picture\">" +
                "<pic:nvPicPr>" +
                "<pic:cNvPr id=\"" + id +"\" name=\"Generated\"/>" +
                "<pic:cNvPicPr/>" +
                "</pic:nvPicPr>" +
                "<pic:blipFill>" +
                "<a:blip r:embed=\"" + blipId +"\"/>" +
                "<a:stretch>" +
                "<a:fillRect/>" +
                "</a:stretch>" +
                "</pic:blipFill>" +
                "<pic:spPr>" +
                "<a:xfrm>" +
                "<a:off x=\"0\" y=\"0\"/>" +
                "<a:ext cx=\"" + width +"\" cy=\"" + height +"\"/>" +
                "</a:xfrm>" +
                "<a:prstGeom prst=\"rect\">" +
                "<a:avLst/>" +
                "</a:prstGeom>" +
                "</pic:spPr>" +
                "</pic:pic>" +
                "</a:graphicData>" +
                "</a:graphic>" +
                "</wp:anchor>";
        XmlToken xmlToken = null;
        try {
            xmlToken = XmlToken.Factory.parse(xml);
        } catch(XmlException xe) {
            xe.printStackTrace();
        }
        drawing.set(xmlToken);
//        drawing.removeInline(0);
    }

    /**
     * 插入嵌入类型图片
     * @param run
     * @param blipId
     * @param id
     * @param width
     * @param height
     */
    public static void createInlinePicture(XWPFRun run, String blipId, int id, int width, int height) {
        final int EMU = 9525;
        width *= EMU;
        height *= EMU;
        CTInline inline = run.getCTR().addNewDrawing().addNewInline();
        XmlToken xmlToken = null;
        try {
            xmlToken = XmlToken.Factory.parse(getPicXml(id, blipId, width, height));
        } catch(XmlException xe) {
            xe.printStackTrace();
        }
        inline.set(xmlToken);

        inline.setDistT(0);
        inline.setDistB(0);
        inline.setDistL(0);
        inline.setDistR(0);

        CTPositiveSize2D extent = inline.addNewExtent();
        extent.setCx(width);
        extent.setCy(height);

        CTNonVisualDrawingProps docPr = inline.addNewDocPr();
        docPr.setId(id);
        docPr.setName("Picture " + id);
        docPr.setDescr("Generated");
    }
    private static String getPicXml(int id, String blipId, int width, int height){
        return
                "<a:graphic xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\">" +
                "   <a:graphicData uri=\"http://schemas.openxmlformats.org/drawingml/2006/picture\">" +
                "      <pic:pic xmlns:pic=\"http://schemas.openxmlformats.org/drawingml/2006/picture\">" +
                "         <pic:nvPicPr>" +
                "            <pic:cNvPr id=\"" + id + "\" name=\"Generated\"/>" +
                "            <pic:cNvPicPr/>" +
                "         </pic:nvPicPr>" +
                "         <pic:blipFill>" +
                "            <a:blip r:embed=\"" + blipId + "\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\"/>" +
                "            <a:stretch>" +
                "               <a:fillRect/>" +
                "            </a:stretch>" +
                "         </pic:blipFill>" +
                "         <pic:spPr>" +
                "            <a:xfrm>" +
                "               <a:off x=\"0\" y=\"0\"/>" +
                "               <a:ext cx=\"" + width + "\" cy=\"" + height + "\"/>" +
                "            </a:xfrm>" +
                "            <a:prstGeom prst=\"rect\">" +
                "               <a:avLst/>" +
                "            </a:prstGeom>" +
                "         </pic:spPr>" +
                "      </pic:pic>" +
                "   </a:graphicData>" +
                "</a:graphic>";
    }
}
