package com.lqkj.generator.entity;

import com.lqkj.common.core.model.BaseEntity;
import com.lqkj.common.utils.StringUtils;

/**
 * 代码生成业务字段表 gen_table_column
 * 
 * @author lh
 */
public class GenTableColumn extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 编号 */
    private Long columnId;

    /** 归属表编号 */
    private Long tableId;

    /** 列名称 */
    private String columnName;

    /** 列描述 */
    private String columnComment;

    /** 列类型 */
    private String columnType;

    /** JAVA类型 */
    private String javaType;

    /** JAVA字段名 */
    private String javaField;

    /** 是否主键（1是） */
    private Boolean isPk;

    /** 是否自增（1是） */
    private Boolean isIncrement;

    /** 是否必填（1是） */
    private Boolean isRequired;

    /** 是否为插入字段（1是） */
    private Boolean isInsert;

    /** 是否编辑字段（1是） */
    private Boolean isEdit;

    /** 是否列表字段（1是） */
    private Boolean isList;

    /** 是否查询字段（1是） */
    private Boolean isQuery;

    /** 查询方式（EQ等于、NE不等于、GT大于、LT小于、LIKE模糊、BETWEEN范围） */
    private String queryType;

    /** 显示类型（input文本框、textarea文本域、select下拉框、checkbox复选框、radio单选框、datetime日期控件、image图片上传控件、upload文件上传控件、editor富文本控件） */
    private String htmlType;

    /** 字典类型 */
    private String dictType;

    /** 排序 */
    private Integer orderNum;

    public void setColumnId(Long columnId)
    {
        this.columnId = columnId;
    }

    public Long getColumnId()
    {
        return columnId;
    }

    public void setTableId(Long tableId)
    {
        this.tableId = tableId;
    }

    public Long getTableId()
    {
        return tableId;
    }

    public void setColumnName(String columnName)
    {
        this.columnName = columnName;
    }

    public String getColumnName()
    {
        return columnName;
    }

    public void setColumnComment(String columnComment)
    {
        this.columnComment = columnComment;
    }

    public String getColumnComment()
    {
        return columnComment;
    }

    public void setColumnType(String columnType)
    {
        this.columnType = columnType;
    }

    public String getColumnType()
    {
        return columnType;
    }

    public void setJavaType(String javaType)
    {
        this.javaType = javaType;
    }

    public String getJavaType()
    {
        return javaType;
    }

    public void setJavaField(String javaField)
    {
        this.javaField = javaField;
    }

    public String getJavaField()
    {
        return javaField;
    }

    public String getCapJavaField()
    {
        return StringUtils.capitalize(javaField);
    }

    public void setIsPk(Boolean isPk)
    {
        this.isPk = isPk;
    }

    public Boolean getIsPk()
    {
        return isPk;
    }


    public Boolean getIsIncrement()
    {
        return isIncrement;
    }

    public void setIsIncrement(Boolean isIncrement)
    {
        this.isIncrement = isIncrement;
    }


    public void setIsRequired(Boolean isRequired)
    {
        this.isRequired = isRequired;
    }

    public Boolean getIsRequired()
    {
        return isRequired;
    }



    public void setIsInsert(Boolean isInsert)
    {
        this.isInsert = isInsert;
    }

    public Boolean getIsInsert()
    {
        return isInsert;
    }


    public void setIsEdit(Boolean isEdit)
    {
        this.isEdit = isEdit;
    }

    public Boolean getIsEdit()
    {
        return isEdit;
    }


    public void setIsList(Boolean isList)
    {
        this.isList = isList;
    }

    public Boolean getIsList()
    {
        return isList;
    }


    public void setIsQuery(Boolean isQuery)
    {
        this.isQuery = isQuery;
    }

    public Boolean getIsQuery()
    {
        return isQuery;
    }


    public void setQueryType(String queryType)
    {
        this.queryType = queryType;
    }

    public String getQueryType()
    {
        return queryType;
    }

    public String getHtmlType()
    {
        return htmlType;
    }

    public void setHtmlType(String htmlType)
    {
        this.htmlType = htmlType;
    }

    public void setDictType(String dictType)
    {
        this.dictType = dictType;
    }

    public String getDictType()
    {
        return dictType;
    }


    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }

    public boolean isSuperColumn()
    {
        return isSuperColumn(this.javaField);
    }

    public static boolean isSuperColumn(String javaField)
    {
        return StringUtils.equalsAnyIgnoreCase(javaField,
                // BaseEntity
                "createBy", "createTime", "updateBy", "updateTime", "remark",
                // TreeEntity
                "parentName", "parentId", "orderNum", "ancestors");
    }

    public boolean isUsableColumn()
    {
        return isUsableColumn(javaField);
    }

    public static boolean isUsableColumn(String javaField)
    {
        // isSuperColumn()中的名单用于避免生成多余Domain属性，若某些属性在生成页面时需要用到不能忽略，则放在此处白名单
        return StringUtils.equalsAnyIgnoreCase(javaField, "parentId", "orderNum", "remark");
    }

    public String readConverterExp()
    {
        String remarks = StringUtils.substringBetween(this.columnComment, "（", "）");
        if (StringUtils.isNotEmpty(remarks))
        {
            return remarks;
        }
        else
        {
            return this.columnComment;
        }
    }
}
