package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.BuildingInfo;
import com.lqkj.info.service.BuildingInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 大楼信息Controller
 * 
 * @author lqkj
 * @date 2024-11-12
 */
@Api(tags = {"大楼信息"})
@RestController
@RequestMapping("/info/buildingInfo")
public class BuildingInfoController extends BaseController
{
    @Autowired
    private BuildingInfoService buildingInfoService;

    /**
     * 查询大楼信息列表
     */
    @ApiOperation("查询大楼信息列表")
    @PreAuthorize("@ss.hasPermi('info:buildingInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(BuildingInfo buildingInfo)
    {
        startPage( buildingInfo);
        PageInfo<BuildingInfo> pageInfo = new PageInfo<>(buildingInfoService.selectBuildingInfoList(buildingInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出大楼信息列表
     */
    @ApiOperation("导出大楼信息列表")
    @PreAuthorize("@ss.hasPermi('info:buildingInfo:export')")
    @Log(title = "大楼信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(BuildingInfo buildingInfo)
    {
        List<BuildingInfo> list = buildingInfoService.selectBuildingInfoList(buildingInfo);
        ExcelUtil<BuildingInfo> util = new ExcelUtil<BuildingInfo>(BuildingInfo.class);
        return util.exportExcel(list, "大楼信息数据");
    }

    /**
     * 获取大楼信息详细信息
     */
    @ApiOperation("获取大楼信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:buildingInfo:query')")
    @GetMapping(value = "/{buildingId}")
    public ResultUtil getInfo(@PathVariable("buildingId") Integer buildingId)
    {
        return ResultUtil.success(buildingInfoService.selectBuildingInfoByBuildingId(buildingId));
    }

    /**
     * 新增大楼信息
     */
    @ApiOperation("新增大楼信息")
    @PreAuthorize("@ss.hasPermi('info:buildingInfo:add')")
    @Log(title = "大楼信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody BuildingInfo buildingInfo)
    {
        return resultByRows(buildingInfoService.insertBuildingInfo(buildingInfo));
    }

    /**
     * 修改大楼信息
     */
    @ApiOperation("修改大楼信息")
    @PreAuthorize("@ss.hasPermi('info:buildingInfo:edit')")
    @Log(title = "大楼信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody BuildingInfo buildingInfo)
    {
        return resultByRows(buildingInfoService.updateBuildingInfo(buildingInfo));
    }

    /**
     * 删除大楼信息
     */
    @ApiOperation("删除大楼信息")
    @PreAuthorize("@ss.hasPermi('info:buildingInfo:remove')")
    @Log(title = "大楼信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{buildingIds}")
    public ResultUtil remove(@PathVariable Integer[] buildingIds)
    {
        return resultByRows(buildingInfoService.deleteBuildingInfoByBuildingIds(buildingIds));
    }
}