package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.Developments;
import com.lqkj.info.service.DevelopmentsService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 发展定位：developmentsController
 * 
 * @author lqkj
 * @date 2024-12-13
 */
@Api(tags = {"发展定位：developments"})
@RestController
@RequestMapping("/info/development")
public class DevelopmentsController extends BaseController
{
    @Autowired
    private DevelopmentsService developmentsService;

    /**
     * 查询发展定位：developments列表
     */
    @ApiOperation("查询发展定位：developments列表")
    @PreAuthorize("@ss.hasPermi('info:development:list')")
    @GetMapping("/list")
    public ResultUtil list(Developments developments)
    {
        startPage( developments);
        PageInfo<Developments> pageInfo = new PageInfo<>(developmentsService.selectDevelopmentsList(developments));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出发展定位：developments列表
     */
    @ApiOperation("导出发展定位：developments列表")
    @PreAuthorize("@ss.hasPermi('info:development:export')")
    @Log(title = "发展定位：developments", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(Developments developments)
    {
        List<Developments> list = developmentsService.selectDevelopmentsList(developments);
        ExcelUtil<Developments> util = new ExcelUtil<Developments>(Developments.class);
        return util.exportExcel(list, "发展定位：developments数据");
    }

    /**
     * 获取发展定位：developments详细信息
     */
    @ApiOperation("获取发展定位：developments详细信息")
    @PreAuthorize("@ss.hasPermi('info:development:query')")
    @GetMapping(value = "/{id}")
    public ResultUtil getInfo(@PathVariable("id") Integer id)
    {
        return ResultUtil.success(developmentsService.selectDevelopmentsById(id));
    }

    /**
     * 新增发展定位：developments
     */
    @ApiOperation("新增发展定位：developments")
    @PreAuthorize("@ss.hasPermi('info:development:add')")
    @Log(title = "发展定位：developments", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody Developments developments)
    {
        return resultByRows(developmentsService.insertDevelopments(developments));
    }

    /**
     * 修改发展定位：developments
     */
    @ApiOperation("修改发展定位：developments")
    @PreAuthorize("@ss.hasPermi('info:development:edit')")
    @Log(title = "发展定位：developments", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody Developments developments)
    {
        return resultByRows(developmentsService.updateDevelopments(developments));
    }

    /**
     * 删除发展定位：developments
     */
    @ApiOperation("删除发展定位：developments")
    @PreAuthorize("@ss.hasPermi('info:development:remove')")
    @Log(title = "发展定位：developments", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultUtil remove(@PathVariable Integer[] ids)
    {
        return resultByRows(developmentsService.deleteDevelopmentsByIds(ids));
    }
}