package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.ElevatorInfo;
import com.lqkj.info.service.ElevatorInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 电梯信息Controller
 * 
 * @author lqkj
 * @date 2024-11-12
 */
@Api(tags = {"电梯信息"})
@RestController
@RequestMapping("/info/elevatorInfo")
public class ElevatorInfoController extends BaseController
{
    @Autowired
    private ElevatorInfoService elevatorInfoService;

    /**
     * 查询电梯信息列表
     */
    @ApiOperation("查询电梯信息列表")
    @PreAuthorize("@ss.hasPermi('info:elevatorInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(ElevatorInfo elevatorInfo)
    {
        startPage( elevatorInfo);
        PageInfo<ElevatorInfo> pageInfo = new PageInfo<>(elevatorInfoService.selectElevatorInfoList(elevatorInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出电梯信息列表
     */
    @ApiOperation("导出电梯信息列表")
    @PreAuthorize("@ss.hasPermi('info:elevatorInfo:export')")
    @Log(title = "电梯信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(ElevatorInfo elevatorInfo)
    {
        List<ElevatorInfo> list = elevatorInfoService.selectElevatorInfoList(elevatorInfo);
        ExcelUtil<ElevatorInfo> util = new ExcelUtil<ElevatorInfo>(ElevatorInfo.class);
        return util.exportExcel(list, "电梯信息数据");
    }

    /**
     * 获取电梯信息详细信息
     */
    @ApiOperation("获取电梯信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:elevatorInfo:query')")
    @GetMapping(value = "/{elevatorId}")
    public ResultUtil getInfo(@PathVariable("elevatorId") Integer elevatorId)
    {
        return ResultUtil.success(elevatorInfoService.selectElevatorInfoByElevatorId(elevatorId));
    }

    /**
     * 新增电梯信息
     */
    @ApiOperation("新增电梯信息")
    @PreAuthorize("@ss.hasPermi('info:elevatorInfo:add')")
    @Log(title = "电梯信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody ElevatorInfo elevatorInfo)
    {
        return resultByRows(elevatorInfoService.insertElevatorInfo(elevatorInfo));
    }

    /**
     * 修改电梯信息
     */
    @ApiOperation("修改电梯信息")
    @PreAuthorize("@ss.hasPermi('info:elevatorInfo:edit')")
    @Log(title = "电梯信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody ElevatorInfo elevatorInfo)
    {
        return resultByRows(elevatorInfoService.updateElevatorInfo(elevatorInfo));
    }

    /**
     * 删除电梯信息
     */
    @ApiOperation("删除电梯信息")
    @PreAuthorize("@ss.hasPermi('info:elevatorInfo:remove')")
    @Log(title = "电梯信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{elevatorIds}")
    public ResultUtil remove(@PathVariable Integer[] elevatorIds)
    {
        return resultByRows(elevatorInfoService.deleteElevatorInfoByElevatorIds(elevatorIds));
    }
}