package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.ForewarningInfo;
import com.lqkj.info.service.ForewarningInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 预警信息Controller
 * 
 * @author lqkj
 * @date 2024-11-12
 */
@Api(tags = {"预警信息"})
@RestController
@RequestMapping("/info/forewarningInfo")
public class ForewarningInfoController extends BaseController
{
    @Autowired
    private ForewarningInfoService forewarningInfoService;

    /**
     * 查询预警信息列表
     */
    @ApiOperation("查询预警信息列表")
    @PreAuthorize("@ss.hasPermi('info:forewarningInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(ForewarningInfo forewarningInfo)
    {
        startPage( forewarningInfo);
        PageInfo<ForewarningInfo> pageInfo = new PageInfo<>(forewarningInfoService.selectForewarningInfoList(forewarningInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出预警信息列表
     */
    @ApiOperation("导出预警信息列表")
    @PreAuthorize("@ss.hasPermi('info:forewarningInfo:export')")
    @Log(title = "预警信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(ForewarningInfo forewarningInfo)
    {
        List<ForewarningInfo> list = forewarningInfoService.selectForewarningInfoList(forewarningInfo);
        ExcelUtil<ForewarningInfo> util = new ExcelUtil<ForewarningInfo>(ForewarningInfo.class);
        return util.exportExcel(list, "预警信息数据");
    }

    /**
     * 获取预警信息详细信息
     */
    @ApiOperation("获取预警信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:forewarningInfo:query')")
    @GetMapping(value = "/{forewarningId}")
    public ResultUtil getInfo(@PathVariable("forewarningId") Integer forewarningId)
    {
        return ResultUtil.success(forewarningInfoService.selectForewarningInfoByForewarningId(forewarningId));
    }

    /**
     * 新增预警信息
     */
    @ApiOperation("新增预警信息")
    @PreAuthorize("@ss.hasPermi('info:forewarningInfo:add')")
    @Log(title = "预警信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody ForewarningInfo forewarningInfo)
    {
        return resultByRows(forewarningInfoService.insertForewarningInfo(forewarningInfo));
    }

    /**
     * 修改预警信息
     */
    @ApiOperation("修改预警信息")
    @PreAuthorize("@ss.hasPermi('info:forewarningInfo:edit')")
    @Log(title = "预警信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody ForewarningInfo forewarningInfo)
    {
        return resultByRows(forewarningInfoService.updateForewarningInfo(forewarningInfo));
    }

    /**
     * 删除预警信息
     */
    @ApiOperation("删除预警信息")
    @PreAuthorize("@ss.hasPermi('info:forewarningInfo:remove')")
    @Log(title = "预警信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{forewarningIds}")
    public ResultUtil remove(@PathVariable Integer[] forewarningIds)
    {
        return resultByRows(forewarningInfoService.deleteForewarningInfoByForewarningIds(forewarningIds));
    }
}