package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.ModelInfo;
import com.lqkj.info.service.ModelInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 模型信息Controller
 * 
 * @author lqkj
 * @date 2024-11-23
 */
@Api(tags = {"模型信息"})
@RestController
@RequestMapping("/info/modelInfo")
public class ModelInfoController extends BaseController
{
    @Autowired
    private ModelInfoService modelInfoService;

    /**
     * 查询模型信息列表
     */
    @ApiOperation("查询模型信息列表")
    @PreAuthorize("@ss.hasPermi('info:modelInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(ModelInfo modelInfo)
    {
        startPage( modelInfo);
        PageInfo<ModelInfo> pageInfo = new PageInfo<>(modelInfoService.selectModelInfoList(modelInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出模型信息列表
     */
    @ApiOperation("导出模型信息列表")
    @PreAuthorize("@ss.hasPermi('info:modelInfo:export')")
    @Log(title = "模型信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(ModelInfo modelInfo)
    {
        List<ModelInfo> list = modelInfoService.selectModelInfoList(modelInfo);
        ExcelUtil<ModelInfo> util = new ExcelUtil<ModelInfo>(ModelInfo.class);
        return util.exportExcel(list, "模型信息数据");
    }

    /**
     * 获取模型信息详细信息
     */
    @ApiOperation("获取模型信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:modelInfo:query')")
    @GetMapping(value = "/{modelId}")
    public ResultUtil getInfo(@PathVariable("modelId") Integer modelId)
    {
        return ResultUtil.success(modelInfoService.selectModelInfoByModelId(modelId));
    }

    /**
     * 新增模型信息
     */
    @ApiOperation("新增模型信息")
    @PreAuthorize("@ss.hasPermi('info:modelInfo:add')")
    @Log(title = "模型信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody ModelInfo modelInfo)
    {
        return resultByRows(modelInfoService.insertModelInfo(modelInfo));
    }

    /**
     * 修改模型信息
     */
    @ApiOperation("修改模型信息")
    @PreAuthorize("@ss.hasPermi('info:modelInfo:edit')")
    @Log(title = "模型信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody ModelInfo modelInfo)
    {
        return resultByRows(modelInfoService.updateModelInfo(modelInfo));
    }

    /**
     * 删除模型信息
     */
    @ApiOperation("删除模型信息")
    @PreAuthorize("@ss.hasPermi('info:modelInfo:remove')")
    @Log(title = "模型信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{modelIds}")
    public ResultUtil remove(@PathVariable Integer[] modelIds)
    {
        return resultByRows(modelInfoService.deleteModelInfoByModelIds(modelIds));
    }
}