package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.PlanInfo;
import com.lqkj.info.service.PlanInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 规划对象Controller
 * 
 * @author lqkj
 * @date 2024-11-13
 */
@Api(tags = {"规划对象"})
@RestController
@RequestMapping("/info/planInfo")
public class PlanInfoController extends BaseController
{
    @Autowired
    private PlanInfoService planInfoService;

    /**
     * 查询规划对象列表
     */
    @ApiOperation("查询规划对象列表")
    @PreAuthorize("@ss.hasPermi('info:planInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(PlanInfo planInfo)
    {
        startPage( planInfo);
        PageInfo<PlanInfo> pageInfo = new PageInfo<>(planInfoService.selectPlanInfoList(planInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出规划对象列表
     */
    @ApiOperation("导出规划对象列表")
    @PreAuthorize("@ss.hasPermi('info:planInfo:export')")
    @Log(title = "规划对象", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(PlanInfo planInfo)
    {
        List<PlanInfo> list = planInfoService.selectPlanInfoList(planInfo);
        ExcelUtil<PlanInfo> util = new ExcelUtil<PlanInfo>(PlanInfo.class);
        return util.exportExcel(list, "规划对象数据");
    }

    /**
     * 获取规划对象详细信息
     */
    @ApiOperation("获取规划对象详细信息")
    @PreAuthorize("@ss.hasPermi('info:planInfo:query')")
    @GetMapping(value = "/{planId}")
    public ResultUtil getInfo(@PathVariable("planId") Integer planId)
    {
        return ResultUtil.success(planInfoService.selectPlanInfoByPlanId(planId));
    }

    /**
     * 新增规划对象
     */
    @ApiOperation("新增规划对象")
    @PreAuthorize("@ss.hasPermi('info:planInfo:add')")
    @Log(title = "规划对象", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody PlanInfo planInfo)
    {
        return resultByRows(planInfoService.insertPlanInfo(planInfo));
    }

    /**
     * 修改规划对象
     */
    @ApiOperation("修改规划对象")
    @PreAuthorize("@ss.hasPermi('info:planInfo:edit')")
    @Log(title = "规划对象", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody PlanInfo planInfo)
    {
        return resultByRows(planInfoService.updatePlanInfo(planInfo));
    }

    /**
     * 删除规划对象
     */
    @ApiOperation("删除规划对象")
    @PreAuthorize("@ss.hasPermi('info:planInfo:remove')")
    @Log(title = "规划对象", businessType = BusinessType.DELETE)
	@DeleteMapping("/{planIds}")
    public ResultUtil remove(@PathVariable Integer[] planIds)
    {
        return resultByRows(planInfoService.deletePlanInfoByPlanIds(planIds));
    }
}