package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.PolicyInfo;
import com.lqkj.info.service.PolicyInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 政策信息Controller
 * 
 * @author lqkj
 * @date 2024-11-15
 */
@Api(tags = {"政策信息"})
@RestController
@RequestMapping("/info/policyInfo")
public class PolicyInfoController extends BaseController
{
    @Autowired
    private PolicyInfoService policyInfoService;

    /**
     * 查询政策信息列表
     */
    @ApiOperation("查询政策信息列表")
    @PreAuthorize("@ss.hasPermi('info:policyInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(PolicyInfo policyInfo)
    {
        startPage( policyInfo);
        PageInfo<PolicyInfo> pageInfo = new PageInfo<>(policyInfoService.selectPolicyInfoList(policyInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出政策信息列表
     */
    @ApiOperation("导出政策信息列表")
    @PreAuthorize("@ss.hasPermi('info:policyInfo:export')")
    @Log(title = "政策信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(PolicyInfo policyInfo)
    {
        List<PolicyInfo> list = policyInfoService.selectPolicyInfoList(policyInfo);
        ExcelUtil<PolicyInfo> util = new ExcelUtil<PolicyInfo>(PolicyInfo.class);
        return util.exportExcel(list, "政策信息数据");
    }

    /**
     * 获取政策信息详细信息
     */
    @ApiOperation("获取政策信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:policyInfo:query')")
    @GetMapping(value = "/{policyId}")
    public ResultUtil getInfo(@PathVariable("policyId") Integer policyId)
    {
        return ResultUtil.success(policyInfoService.selectPolicyInfoByPolicyId(policyId));
    }

    /**
     * 新增政策信息
     */
    @ApiOperation("新增政策信息")
    @PreAuthorize("@ss.hasPermi('info:policyInfo:add')")
    @Log(title = "政策信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody PolicyInfo policyInfo)
    {
        return resultByRows(policyInfoService.insertPolicyInfo(policyInfo));
    }

    /**
     * 修改政策信息
     */
    @ApiOperation("修改政策信息")
    @PreAuthorize("@ss.hasPermi('info:policyInfo:edit')")
    @Log(title = "政策信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody PolicyInfo policyInfo)
    {
        return resultByRows(policyInfoService.updatePolicyInfo(policyInfo));
    }

    /**
     * 删除政策信息
     */
    @ApiOperation("删除政策信息")
    @PreAuthorize("@ss.hasPermi('info:policyInfo:remove')")
    @Log(title = "政策信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{policyIds}")
    public ResultUtil remove(@PathVariable Integer[] policyIds)
    {
        return resultByRows(policyInfoService.deletePolicyInfoByPolicyIds(policyIds));
    }
}