package com.lqkj.info.service;

import java.util.List;

import com.lqkj.type.service.BuildingTypeService;
import org.apache.commons.lang.StringEscapeUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.lqkj.info.mapper.BuildingInfoMapper;
import com.lqkj.info.entity.BuildingInfo;
import com.lqkj.common.utils.uuid.IdUtils;
/**
 * 大楼信息Service业务层处理
 * 
 * @author lqkj
 * @date 2024-11-12
 */
@Service
public class BuildingInfoService
{
    @Autowired
    private BuildingInfoMapper buildingInfoMapper;

    @Autowired
    private BuildingTypeService buildingTypeService;

    /**
     * 查询大楼信息
     * 
     * @param buildingId 大楼信息主键
     * @return 大楼信息
     */
    
    public BuildingInfo selectBuildingInfoByBuildingId(Integer buildingId)
    {
        return buildingInfoMapper.selectBuildingInfoByBuildingId(buildingId);
    }

    /**
     * 查询大楼信息列表
     * 
     * @param buildingInfo 大楼信息
     * @return 大楼信息
     */
    public List<BuildingInfo> selectBuildingInfoList(BuildingInfo buildingInfo)
    {
        List<BuildingInfo> buildingInfos = buildingInfoMapper.selectBuildingInfoList(buildingInfo);
        buildingInfos.stream().forEach(b->{
            b.setTypeName(buildingTypeService.selectBuildingTypeByTypeId(b.getTypeId()).getTypeName());
        });
        return buildingInfos;

    }

    /**
     * 新增大楼信息
     * 
     * @param buildingInfo 大楼信息
     * @return 结果
     */
    
    public int insertBuildingInfo(BuildingInfo buildingInfo)
    {
        buildingInfo.setMemo(StringEscapeUtils.unescapeHtml(buildingInfo.getMemo()));
        return buildingInfoMapper.insertBuildingInfo(buildingInfo);
    }

    /**
     * 修改大楼信息
     * 
     * @param buildingInfo 大楼信息
     * @return 结果
     */
    
    public int updateBuildingInfo(BuildingInfo buildingInfo)
    {
        buildingInfo.setMemo(StringEscapeUtils.unescapeHtml(buildingInfo.getMemo()));
        return buildingInfoMapper.updateBuildingInfo(buildingInfo);
    }

    /**
     * 批量删除大楼信息
     * 
     * @param buildingIds 需要删除的大楼信息主键
     * @return 结果
     */
    
    public int deleteBuildingInfoByBuildingIds(Integer[] buildingIds)
    {
        return buildingInfoMapper.deleteBuildingInfoByBuildingIds(buildingIds);
    }

    /**
     * 删除大楼信息信息
     * 
     * @param buildingId 大楼信息主键
     * @return 结果
     */
    
    public int deleteBuildingInfoByBuildingId(Integer buildingId)
    {
        return buildingInfoMapper.deleteBuildingInfoByBuildingId(buildingId);
    }
}