package com.lqkj.info.service;

import java.util.List;
import java.time.LocalDateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.lqkj.info.mapper.ForewarningInfoMapper;
import com.lqkj.info.entity.ForewarningInfo;
import com.lqkj.common.utils.uuid.IdUtils;
/**
 * 预警信息Service业务层处理
 * 
 * @author lqkj
 * @date 2024-11-12
 */
@Service
public class ForewarningInfoService
{
    @Autowired
    private ForewarningInfoMapper forewarningInfoMapper;

    /**
     * 查询预警信息
     * 
     * @param forewarningId 预警信息主键
     * @return 预警信息
     */
    
    public ForewarningInfo selectForewarningInfoByForewarningId(Integer forewarningId)
    {
        return forewarningInfoMapper.selectForewarningInfoByForewarningId(forewarningId);
    }

    /**
     * 查询预警信息列表
     * 
     * @param forewarningInfo 预警信息
     * @return 预警信息
     */
    public List<ForewarningInfo> selectForewarningInfoList(ForewarningInfo forewarningInfo)
    {
        return forewarningInfoMapper.selectForewarningInfoList(forewarningInfo);
    }

    /**
     * 新增预警信息
     * 
     * @param forewarningInfo 预警信息
     * @return 结果
     */
    
    public int insertForewarningInfo(ForewarningInfo forewarningInfo)
    {
        forewarningInfo.setCreateTime(LocalDateTime.now());
        return forewarningInfoMapper.insertForewarningInfo(forewarningInfo);
    }

    /**
     * 修改预警信息
     * 
     * @param forewarningInfo 预警信息
     * @return 结果
     */
    
    public int updateForewarningInfo(ForewarningInfo forewarningInfo)
    {
        return forewarningInfoMapper.updateForewarningInfo(forewarningInfo);
    }

    /**
     * 批量删除预警信息
     * 
     * @param forewarningIds 需要删除的预警信息主键
     * @return 结果
     */
    
    public int deleteForewarningInfoByForewarningIds(Integer[] forewarningIds)
    {
        return forewarningInfoMapper.deleteForewarningInfoByForewarningIds(forewarningIds);
    }

    /**
     * 删除预警信息信息
     * 
     * @param forewarningId 预警信息主键
     * @return 结果
     */
    
    public int deleteForewarningInfoByForewarningId(Integer forewarningId)
    {
        return forewarningInfoMapper.deleteForewarningInfoByForewarningId(forewarningId);
    }
}