package com.lqkj.ioc.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.ioc.entity.SynthesisAnalyze;
import com.lqkj.ioc.service.SynthesisAnalyzeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 综合分析Controller
 * 
 * @author lqkj
 * @date 2024-11-18
 */
@Api(tags = {"综合分析"})
@RestController
@RequestMapping("/view/synthesisAnalyze")
public class SynthesisAnalyzeController extends BaseController
{
    @Autowired
    private SynthesisAnalyzeService synthesisAnalyzeService;

    /**
     * 查询综合分析列表
     */
    @ApiOperation("查询综合分析列表")
    @PreAuthorize("@ss.hasPermi('view:synthesisAnalyze:list')")
    @GetMapping("/list")
    public ResultUtil list(SynthesisAnalyze synthesisAnalyze)
    {
        startPage( synthesisAnalyze);
        PageInfo<SynthesisAnalyze> pageInfo = new PageInfo<>(synthesisAnalyzeService.selectSynthesisAnalyzeList(synthesisAnalyze));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出综合分析列表
     */
    @ApiOperation("导出综合分析列表")
    @PreAuthorize("@ss.hasPermi('view:synthesisAnalyze:export')")
    @Log(title = "综合分析", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(SynthesisAnalyze synthesisAnalyze)
    {
        List<SynthesisAnalyze> list = synthesisAnalyzeService.selectSynthesisAnalyzeList(synthesisAnalyze);
        ExcelUtil<SynthesisAnalyze> util = new ExcelUtil<SynthesisAnalyze>(SynthesisAnalyze.class);
        return util.exportExcel(list, "综合分析数据");
    }

    /**
     * 获取综合分析详细信息
     */
    @ApiOperation("获取综合分析详细信息")
    @PreAuthorize("@ss.hasPermi('view:synthesisAnalyze:query')")
    @GetMapping(value = "/{id}")
    public ResultUtil getInfo(@PathVariable("id") Integer id)
    {
        return ResultUtil.success(synthesisAnalyzeService.selectSynthesisAnalyzeById(id));
    }

    /**
     * 新增综合分析
     */
    @ApiOperation("新增综合分析")
    @PreAuthorize("@ss.hasPermi('view:synthesisAnalyze:add')")
    @Log(title = "综合分析", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody SynthesisAnalyze synthesisAnalyze)
    {
        return resultByRows(synthesisAnalyzeService.insertSynthesisAnalyze(synthesisAnalyze));
    }

    /**
     * 修改综合分析
     */
    @ApiOperation("修改综合分析")
    @PreAuthorize("@ss.hasPermi('view:synthesisAnalyze:edit')")
    @Log(title = "综合分析", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody SynthesisAnalyze synthesisAnalyze)
    {
        return resultByRows(synthesisAnalyzeService.updateSynthesisAnalyze(synthesisAnalyze));
    }

    /**
     * 删除综合分析
     */
    @ApiOperation("删除综合分析")
    @PreAuthorize("@ss.hasPermi('view:synthesisAnalyze:remove')")
    @Log(title = "综合分析", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultUtil remove(@PathVariable Integer[] ids)
    {
        return resultByRows(synthesisAnalyzeService.deleteSynthesisAnalyzeByIds(ids));
    }
}