package com.lqkj.office.service;

import com.lqkj.common.utils.uuid.IdUtils;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.ss.usermodel.PrintSetup;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.jodconverter.DocumentConverter;
import org.jodconverter.office.OfficeException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

/**
 * office文档转pdf等业务操作
 * @author: lh
 */
@Service
public class JodConvertService {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Autowired(required = false)
    private DocumentConverter converter;

    /**
     * word转pdf等
     * @param sourceFile
     * @param targetFile
     * @return
     */
    public boolean convert(File sourceFile, File targetFile){
        try {
            converter.convert(sourceFile).to(targetFile).execute();
            return true;
        } catch (OfficeException e) {
            logger.error("文档转换失败", e);
        }
        return false;
    }

    /**
     * excel转pdf增强方法，能保持列在同一页
     * @param sourceFile
     * @param targetFile
     * @return
     */
    public boolean convertExcelToPDFByFitColumn(File sourceFile, File targetFile) {
        File tempExcel = new File(sourceFile.getParentFile(), IdUtils.simpleUUID().concat("_").concat(sourceFile.getName()));
        try {
            setExcelPrintParameter(sourceFile, tempExcel);
            return this.convert(tempExcel, targetFile);
        } catch (IOException | InvalidFormatException e) {
            logger.error("文档转换失败", e);
        } finally {
            if (tempExcel.exists() && !tempExcel.delete()){
                logger.warn("删除临时文件失败 file={}", tempExcel.getPath());
            }

        }
        return false;
    }
    /**
     * 设置Excel打印参数
     *
     * @param sourceFile
     * @param targetFile
     * @throws IOException
     * @throws InvalidFormatException
     */
    private void setExcelPrintParameter(File sourceFile, File targetFile) throws IOException, InvalidFormatException {
        Workbook workbook = new XSSFWorkbook(sourceFile);
        for (int i = 0, j = workbook.getNumberOfSheets(); i < j; i++) {
            Sheet sheet = workbook.getSheetAt(i);
            sheet.getPrintSetup().setPaperSize(PrintSetup.A4_PAPERSIZE);
            sheet.setFitToPage(true);
            sheet.getPrintSetup().setFitWidth((short) 1);
            // 是否显示自动换页符
            sheet.setAutobreaks(true);
        }
        try (FileOutputStream out = new FileOutputStream(targetFile)) {
            workbook.write(out);
            workbook.close();
        }
    }
}
