package com.lqkj.supporting.controller;

import java.util.List;

import org.apache.ibatis.annotations.Param;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.supporting.entity.ResourcesInfo;
import com.lqkj.supporting.service.ResourcesInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 资源点位对象Controller
 *
 * @author lqkj
 * @date 2025-05-07
 */
@Api(tags = {"资源点位对象"})
@RestController
@RequestMapping("/supporting/info")
public class ResourcesInfoController extends BaseController
{
    @Autowired
    private ResourcesInfoService resourcesInfoService;

    /**
     * 查询资源点位对象列表
     */
    @ApiOperation("查询资源点位对象列表")
    @PreAuthorize("@ss.hasPermi('supporting:info:list')")
    @GetMapping("/list")
    public ResultUtil list(ResourcesInfo resourcesInfo)
    {
        startPage( resourcesInfo);
        PageInfo<ResourcesInfo> pageInfo = new PageInfo<>(resourcesInfoService.selectResourcesInfoList(resourcesInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出资源点位对象列表
     */
    @ApiOperation("导出资源点位对象列表")
    @PreAuthorize("@ss.hasPermi('supporting:info:export')")
    @Log(title = "资源点位对象", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(ResourcesInfo resourcesInfo)
    {
        List<ResourcesInfo> list = resourcesInfoService.selectResourcesInfoList(resourcesInfo);
        ExcelUtil<ResourcesInfo> util = new ExcelUtil<ResourcesInfo>(ResourcesInfo.class);
        return util.exportExcel(list, "资源点位对象数据");
    }

    /**
     * 获取资源点位对象详细信息
     */
    @ApiOperation("获取资源点位对象详细信息")
    @PreAuthorize("@ss.hasPermi('supporting:info:query')")
    @GetMapping(value = "/{infoId}")
    public ResultUtil getInfo(@PathVariable("infoId") Integer infoId)
    {
        return ResultUtil.success(resourcesInfoService.selectResourcesInfoByInfoId(infoId));
    }

    /**
     * 新增资源点位对象
     */
    @ApiOperation("新增资源点位对象")
    @PreAuthorize("@ss.hasPermi('supporting:info:add')")
    @Log(title = "资源点位对象", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody ResourcesInfo resourcesInfo)
    {
        return resultByRows(resourcesInfoService.insertResourcesInfo(resourcesInfo));
    }

    /**
     * 修改资源点位对象
     */
    @ApiOperation("修改资源点位对象")
    @PreAuthorize("@ss.hasPermi('supporting:info:edit')")
    @Log(title = "资源点位对象", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody ResourcesInfo resourcesInfo)
    {
        return resultByRows(resourcesInfoService.updateResourcesInfo(resourcesInfo));
    }

    /**
     * 删除资源点位对象
     */
    @ApiOperation("删除资源点位对象")
    @PreAuthorize("@ss.hasPermi('supporting:info:remove')")
    @Log(title = "资源点位对象", businessType = BusinessType.DELETE)
	@DeleteMapping("/{infoIds}")
    public ResultUtil remove(@PathVariable Integer[] infoIds)
    {
        return resultByRows(resourcesInfoService.deleteResourcesInfoByInfoIds(infoIds));
    }

    /**
     * 根据geom查询资源点位对象
     * @param location 点位对象
     * @param distance 距离
     * @return 点位集合
     */
    @GetMapping("/listByGeom")
    public List<ResourcesInfo> selectResourcesInfoListByGeom(@Param("location") String location, @Param("distance") int distance ){
        return resourcesInfoService.selectResourcesInfoListByGeom(location,distance);
    }

}
