package com.lqkj.supporting.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.lqkj.supporting.entity.ResourcesInfo;
import org.apache.ibatis.annotations.Select;
import org.springframework.data.repository.query.Param;

/**
 * 资源点位对象Mapper接口
 *
 * @author lqkj
 * @date 2025-05-07
 */
@Mapper
public interface ResourcesInfoMapper
{
    /**
     * 查询资源点位对象
     *
     * @param infoId 资源点位对象主键
     * @return 资源点位对象
     */
    public ResourcesInfo selectResourcesInfoByInfoId(Integer infoId);

    /**
     * 查询资源点位对象列表
     *
     * @param resourcesInfo 资源点位对象
     * @return 资源点位对象集合
     */
    public List<ResourcesInfo> selectResourcesInfoList(ResourcesInfo resourcesInfo);

    /**
     * 新增资源点位对象
     *
     * @param resourcesInfo 资源点位对象
     * @return 结果
     */
    public int insertResourcesInfo(ResourcesInfo resourcesInfo);

    /**
     * 修改资源点位对象
     *
     * @param resourcesInfo 资源点位对象
     * @return 结果
     */
    public int updateResourcesInfo(ResourcesInfo resourcesInfo);

    /**
     * 删除资源点位对象
     *
     * @param infoId 资源点位对象主键
     * @return 结果
     */
    public int deleteResourcesInfoByInfoId(Integer infoId);

    /**
     * 批量删除资源点位对象
     *
     * @param infoIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteResourcesInfoByInfoIds(Integer[] infoIds);

    /**
     * 根据geom查询资源点位对象
     * @param location 点位对象
     * @param distance 距离
     * @return 点位集合
     */
//    @Select("select info_id,type_id,info_name,location,memo,CAST(st_distancesphere(ST_SetSRID(st_geomfromgeojson(location),4326), st_geomfromgeojson(#{location})) AS NUMERIC(10,2)) distance from resources_info  \n" +
//            "        where st_distancesphere(ST_SetSRID(st_geomfromgeojson(location),4326), st_geomfromgeojson(#{location})) <= :distance \n" +
//            "        order by st_distancesphere(ST_SetSRID(st_geomfromgeojson(location),4326), st_geomfromgeojson(#{location})) limit 5")
    public List<ResourcesInfo> selectResourcesInfoListByGeom(Object location,int distance);
}
