package com.lqkj.supporting.service;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.lqkj.common.utils.GeoUtils;
import com.lqkj.supporting.entity.ResourcesType;
import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.Point;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.lqkj.supporting.mapper.ResourcesInfoMapper;
import com.lqkj.supporting.entity.ResourcesInfo;
import com.lqkj.common.utils.uuid.IdUtils;
import org.springframework.util.CollectionUtils;

/**
 * 资源点位对象Service业务层处理
 *
 * @author lqkj
 * @date 2025-05-07
 */
@Service
public class ResourcesInfoService {
    @Autowired
    private ResourcesInfoMapper resourcesInfoMapper;

    @Autowired
    private ResourcesTypeService resourcesTypeService;

    /**
     * 查询资源点位对象
     *
     * @param infoId 资源点位对象主键
     * @return 资源点位对象
     */

    public ResourcesInfo selectResourcesInfoByInfoId(Integer infoId) {
        ResourcesInfo resourcesInfo = resourcesInfoMapper.selectResourcesInfoByInfoId(infoId);
        paseGeom(resourcesInfo);
        return resourcesInfo;
    }

    private void paseGeom(ResourcesInfo resourcesInfo) {
        Object location = resourcesInfo.getLocation();
        System.out.println(location.getClass());
        Map<String, Object> map = (LinkedHashMap<String, Object>) location;
        // 假设该 Map 来自 GeoJSON 格式，可以手动提取坐标并构造 Point
        List coordinates = (ArrayList) map.get("coordinates");

        resourcesInfo.setLocation(coordinates.get(0).toString()  + "," + coordinates.get(1).toString());
        Integer typeId = resourcesInfo.getTypeId();
        ResourcesType resourcesType = resourcesTypeService.selectResourcesTypeByTypeId(typeId);
        resourcesInfo.setTypeName(resourcesType.getTypeName());
    }

    /**
     * 查询资源点位对象列表
     *
     * @param resourcesInfo 资源点位对象
     * @return 资源点位对象
     */
    public List<ResourcesInfo> selectResourcesInfoList(ResourcesInfo resourcesInfo) {
        List<ResourcesInfo> resourcesInfos = resourcesInfoMapper.selectResourcesInfoList(resourcesInfo);
        if (!CollectionUtils.isEmpty(resourcesInfos)) {
            resourcesInfos.forEach(resourcesInfo1 -> {
                paseGeom(resourcesInfo1);
            });
        }
        return resourcesInfos;
    }

    /**
     * 新增资源点位对象
     *
     * @param resourcesInfo 资源点位对象
     * @return 结果
     */

    public int insertResourcesInfo(ResourcesInfo resourcesInfo) {

        String location = (String) resourcesInfo.getLocation();
        Point point = GeoUtils.createPoint(location);
        JSONObject jsonObject = GeoUtils.readFromGeometry(point);
        resourcesInfo.setLocation(jsonObject);
        return resourcesInfoMapper.insertResourcesInfo(resourcesInfo);
    }

    /**
     * 修改资源点位对象
     *
     * @param resourcesInfo 资源点位对象
     * @return 结果
     */

    public int updateResourcesInfo(ResourcesInfo resourcesInfo) {
//        String location = resourcesInfo.getLocation();
//        Point point = GeoUtils.createPoint(location);
//        JSONObject jsonObject = GeoUtils.readFromGeometry(point);
//        resourcesInfo.setLocation(jsonObject.toJSONString());
        return resourcesInfoMapper.updateResourcesInfo(resourcesInfo);
    }

    /**
     * 批量删除资源点位对象
     *
     * @param infoIds 需要删除的资源点位对象主键
     * @return 结果
     */

    public int deleteResourcesInfoByInfoIds(Integer[] infoIds) {
        return resourcesInfoMapper.deleteResourcesInfoByInfoIds(infoIds);
    }

    /**
     * 删除资源点位对象信息
     *
     * @param infoId 资源点位对象主键
     * @return 结果
     */

    public int deleteResourcesInfoByInfoId(Integer infoId) {
        return resourcesInfoMapper.deleteResourcesInfoByInfoId(infoId);
    }

    /**
     * 根据geom查询资源点位对象
     * @param location 点位对象
     * @param distance 距离
     * @return 点位集合
     */
    public List<ResourcesInfo> selectResourcesInfoListByGeom(String location,int distance){
        Point point = GeoUtils.createPoint(location);
        JSONObject jsonObject = GeoUtils.readFromGeometry(point);
        List<ResourcesInfo> resourcesInfos = resourcesInfoMapper.selectResourcesInfoListByGeom(jsonObject, distance);
        if (!CollectionUtils.isEmpty(resourcesInfos)) {
            resourcesInfos.forEach(this::paseGeom);
        }

        return resourcesInfos;
    }


}
