package com.lqkj.system.controller;


import com.lqkj.ApiVersion;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.utils.SecurityUtils;
import com.lqkj.framework.service.SysPermissionService;
import com.lqkj.system.entity.SysMenu;
import com.lqkj.system.entity.SysUser;
import com.lqkj.system.service.SysMenuService;
import com.lqkj.system.service.SysUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Set;

/**
 * 登录验证
 * 
 * @author lh
 */
@Api(tags = {"用户登录信息"})
@RestController
@RequestMapping("/" + ApiVersion.V1)
public class SysLoginController {
    @Autowired
    private SysMenuService menuService;
    @Autowired
    private SysUserService userService;
    @Autowired
    private SysPermissionService permissionService;

    /**
     * 获取用户信息
     * 
     * @return 用户信息
     */
    @ApiOperation("获取用户信息")
    @GetMapping("/getInfo")
    public ResultUtil getInfo()
    {
        SysUser user = userService.selectUserById(SecurityUtils.getLoginUser().getUser().getUserId());

        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);
        ResultUtil result = ResultUtil.success();
        result.put("user", user);
        result.put("roles", roles);
        result.put("permissions", permissions);
        return result;
    }

    /**
     * 获取路由信息
     * 
     * @return 路由信息
     */
    @ApiOperation("获取路由信息")
    @GetMapping("/getRouters")
    public ResultUtil getRouters()
    {
        String userId = SecurityUtils.getUserId();
        List<SysMenu> menus = menuService.selectMenuTreeByUserId(userId);
        return ResultUtil.success(menuService.buildMenus(menus));
    }
}
