package com.lqkj.type.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.type.entity.AreaType;
import com.lqkj.type.service.AreaTypeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 区域类型：area_typeController
 *
 * @author lqkj
 * @date 2024-11-11
 */
@Api(tags = {"区域类型：area_type"})
@RestController
@RequestMapping("/type/areaType")
public class AreaTypeController extends BaseController
{
    @Autowired
    private AreaTypeService areaTypeService;

    /**
     * 查询区域类型：area_type列表
     */
    @ApiOperation("查询区域类型：area_type列表")
    @PreAuthorize("@ss.hasPermi('type:areaType:list')")
    @GetMapping("/list")
    public ResultUtil list(AreaType areaType)
    {
        startPage( areaType);
        PageInfo<AreaType> pageInfo = new PageInfo<>(areaTypeService.selectAreaTypeList(areaType));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出区域类型：area_type列表
     */
    @ApiOperation("导出区域类型：area_type列表")
    @PreAuthorize("@ss.hasPermi('type:areaType:export')")
    @Log(title = "区域类型：area_type", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(AreaType areaType)
    {
        List<AreaType> list = areaTypeService.selectAreaTypeList(areaType);
        ExcelUtil<AreaType> util = new ExcelUtil<AreaType>(AreaType.class);
        return util.exportExcel(list, "区域类型：area_type数据");
    }

    /**
     * 获取区域类型：area_type详细信息
     */
    @ApiOperation("获取区域类型：area_type详细信息")
    @PreAuthorize("@ss.hasPermi('type:areaType:query')")
    @GetMapping(value = "/{typeId}")
    public ResultUtil getInfo(@PathVariable("typeId") Integer typeId)
    {
        return ResultUtil.success(areaTypeService.selectAreaTypeByTypeId(typeId));
    }

    /**
     * 新增区域类型：area_type
     */
    @ApiOperation("新增区域类型：area_type")
    @PreAuthorize("@ss.hasPermi('type:areaType:add')")
    @Log(title = "区域类型：area_type", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody AreaType areaType)
    {
        return resultByRows(areaTypeService.insertAreaType(areaType));
    }

    /**
     * 修改区域类型：area_type
     */
    @ApiOperation("修改区域类型：area_type")
    @PreAuthorize("@ss.hasPermi('type:areaType:edit')")
    @Log(title = "区域类型：area_type", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody AreaType areaType)
    {
        return resultByRows(areaTypeService.updateAreaType(areaType));
    }

    /**
     * 删除区域类型：area_type
     */
    @ApiOperation("删除区域类型：area_type")
    @PreAuthorize("@ss.hasPermi('type:areaType:remove')")
    @Log(title = "区域类型：area_type", businessType = BusinessType.DELETE)
    @DeleteMapping("/{typeIds}")
    public ResultUtil remove(@PathVariable Integer[] typeIds)
    {
        return resultByRows(areaTypeService.deleteAreaTypeByTypeIds(typeIds));
    }
}