package com.lqkj.type.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.type.entity.BuildingType;
import com.lqkj.type.service.BuildingTypeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 大楼类别：building_typeController
 * 
 * @author lqkj
 * @date 2024-11-11
 */
@Api(tags = {"大楼类别：building_type"})
@RestController
@RequestMapping("/type/buildingType")
public class BuildingTypeController extends BaseController
{
    @Autowired
    private BuildingTypeService buildingTypeService;

    /**
     * 查询大楼类别：building_type列表
     */
    @ApiOperation("查询大楼类别：building_type列表")
    @PreAuthorize("@ss.hasPermi('type:buildingType:list')")
    @GetMapping("/list")
    public ResultUtil list(BuildingType buildingType)
    {
        startPage( buildingType);
        PageInfo<BuildingType> pageInfo = new PageInfo<>(buildingTypeService.selectBuildingTypeList(buildingType));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出大楼类别：building_type列表
     */
    @ApiOperation("导出大楼类别：building_type列表")
    @PreAuthorize("@ss.hasPermi('type:buildingType:export')")
    @Log(title = "大楼类别：building_type", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(BuildingType buildingType)
    {
        List<BuildingType> list = buildingTypeService.selectBuildingTypeList(buildingType);
        ExcelUtil<BuildingType> util = new ExcelUtil<BuildingType>(BuildingType.class);
        return util.exportExcel(list, "大楼类别：building_type数据");
    }

    /**
     * 获取大楼类别：building_type详细信息
     */
    @ApiOperation("获取大楼类别：building_type详细信息")
    @PreAuthorize("@ss.hasPermi('type:buildingType:query')")
    @GetMapping(value = "/{typeId}")
    public ResultUtil getInfo(@PathVariable("typeId") Integer typeId)
    {
        return ResultUtil.success(buildingTypeService.selectBuildingTypeByTypeId(typeId));
    }

    /**
     * 新增大楼类别：building_type
     */
    @ApiOperation("新增大楼类别：building_type")
    @PreAuthorize("@ss.hasPermi('type:buildingType:add')")
    @Log(title = "大楼类别：building_type", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody BuildingType buildingType)
    {
        return resultByRows(buildingTypeService.insertBuildingType(buildingType));
    }

    /**
     * 修改大楼类别：building_type
     */
    @ApiOperation("修改大楼类别：building_type")
    @PreAuthorize("@ss.hasPermi('type:buildingType:edit')")
    @Log(title = "大楼类别：building_type", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody BuildingType buildingType)
    {
        return resultByRows(buildingTypeService.updateBuildingType(buildingType));
    }

    /**
     * 删除大楼类别：building_type
     */
    @ApiOperation("删除大楼类别：building_type")
    @PreAuthorize("@ss.hasPermi('type:buildingType:remove')")
    @Log(title = "大楼类别：building_type", businessType = BusinessType.DELETE)
	@DeleteMapping("/{typeIds}")
    public ResultUtil remove(@PathVariable Integer[] typeIds)
    {
        return resultByRows(buildingTypeService.deleteBuildingTypeByTypeIds(typeIds));
    }
}