package com.lqkj.type.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.type.entity.EquipmentType;
import com.lqkj.type.service.EquipmentTypeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 设备类型：equipment_typeController
 * 
 * @author lqkj
 * @date 2024-11-11
 */
@Api(tags = {"设备类型：equipment_type"})
@RestController
@RequestMapping("/type/equipmentType")
public class EquipmentTypeController extends BaseController
{
    @Autowired
    private EquipmentTypeService equipmentTypeService;

    /**
     * 查询设备类型：equipment_type列表
     */
    @ApiOperation("查询设备类型：equipment_type列表")
    @PreAuthorize("@ss.hasPermi('type:equipmentType:list')")
    @GetMapping("/list")
    public ResultUtil list(EquipmentType equipmentType)
    {
        startPage( equipmentType);
        PageInfo<EquipmentType> pageInfo = new PageInfo<>(equipmentTypeService.selectEquipmentTypeList(equipmentType));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出设备类型：equipment_type列表
     */
    @ApiOperation("导出设备类型：equipment_type列表")
    @PreAuthorize("@ss.hasPermi('type:equipmentType:export')")
    @Log(title = "设备类型：equipment_type", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(EquipmentType equipmentType)
    {
        List<EquipmentType> list = equipmentTypeService.selectEquipmentTypeList(equipmentType);
        ExcelUtil<EquipmentType> util = new ExcelUtil<EquipmentType>(EquipmentType.class);
        return util.exportExcel(list, "设备类型：equipment_type数据");
    }

    /**
     * 获取设备类型：equipment_type详细信息
     */
    @ApiOperation("获取设备类型：equipment_type详细信息")
    @PreAuthorize("@ss.hasPermi('type:equipmentType:query')")
    @GetMapping(value = "/{typeId}")
    public ResultUtil getInfo(@PathVariable("typeId") Integer typeId)
    {
        return ResultUtil.success(equipmentTypeService.selectEquipmentTypeByTypeId(typeId));
    }

    /**
     * 新增设备类型：equipment_type
     */
    @ApiOperation("新增设备类型：equipment_type")
    @PreAuthorize("@ss.hasPermi('type:equipmentType:add')")
    @Log(title = "设备类型：equipment_type", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody EquipmentType equipmentType)
    {
        return resultByRows(equipmentTypeService.insertEquipmentType(equipmentType));
    }

    /**
     * 修改设备类型：equipment_type
     */
    @ApiOperation("修改设备类型：equipment_type")
    @PreAuthorize("@ss.hasPermi('type:equipmentType:edit')")
    @Log(title = "设备类型：equipment_type", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody EquipmentType equipmentType)
    {
        return resultByRows(equipmentTypeService.updateEquipmentType(equipmentType));
    }

    /**
     * 删除设备类型：equipment_type
     */
    @ApiOperation("删除设备类型：equipment_type")
    @PreAuthorize("@ss.hasPermi('type:equipmentType:remove')")
    @Log(title = "设备类型：equipment_type", businessType = BusinessType.DELETE)
	@DeleteMapping("/{typeIds}")
    public ResultUtil remove(@PathVariable Integer[] typeIds)
    {
        return resultByRows(equipmentTypeService.deleteEquipmentTypeByTypeIds(typeIds));
    }
}