package com.lqkj.type.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.type.entity.OrganizationType;
import com.lqkj.type.service.OrganizationTypeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 主体类型Controller
 * 
 * @author lqkj
 * @date 2024-11-11
 */
@Api(tags = {"主体类型"})
@RestController
@RequestMapping("/type/organizationType")
public class OrganizationTypeController extends BaseController
{
    @Autowired
    private OrganizationTypeService organizationTypeService;

    /**
     * 查询主体类型列表
     */
    @ApiOperation("查询主体类型列表")
    @PreAuthorize("@ss.hasPermi('type:organizationType:list')")
    @GetMapping("/list")
    public ResultUtil list(OrganizationType organizationType)
    {
        startPage( organizationType);
        PageInfo<OrganizationType> pageInfo = new PageInfo<>(organizationTypeService.selectOrganizationTypeList(organizationType));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出主体类型列表
     */
    @ApiOperation("导出主体类型列表")
    @PreAuthorize("@ss.hasPermi('type:organizationType:export')")
    @Log(title = "主体类型", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(OrganizationType organizationType)
    {
        List<OrganizationType> list = organizationTypeService.selectOrganizationTypeList(organizationType);
        ExcelUtil<OrganizationType> util = new ExcelUtil<OrganizationType>(OrganizationType.class);
        return util.exportExcel(list, "主体类型数据");
    }

    /**
     * 获取主体类型详细信息
     */
    @ApiOperation("获取主体类型详细信息")
    @PreAuthorize("@ss.hasPermi('type:organizationType:query')")
    @GetMapping(value = "/{typeId}")
    public ResultUtil getInfo(@PathVariable("typeId") Integer typeId)
    {
        return ResultUtil.success(organizationTypeService.selectOrganizationTypeByTypeId(typeId));
    }

    /**
     * 新增主体类型
     */
    @ApiOperation("新增主体类型")
    @PreAuthorize("@ss.hasPermi('type:organizationType:add')")
    @Log(title = "主体类型", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody OrganizationType organizationType)
    {
        return resultByRows(organizationTypeService.insertOrganizationType(organizationType));
    }

    /**
     * 修改主体类型
     */
    @ApiOperation("修改主体类型")
    @PreAuthorize("@ss.hasPermi('type:organizationType:edit')")
    @Log(title = "主体类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody OrganizationType organizationType)
    {
        return resultByRows(organizationTypeService.updateOrganizationType(organizationType));
    }

    /**
     * 删除主体类型
     */
    @ApiOperation("删除主体类型")
    @PreAuthorize("@ss.hasPermi('type:organizationType:remove')")
    @Log(title = "主体类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{typeIds}")
    public ResultUtil remove(@PathVariable Integer[] typeIds)
    {
        return resultByRows(organizationTypeService.deleteOrganizationTypeByTypeIds(typeIds));
    }
}